pub enum SendLaunchpadError {
Show 35 variants
TokenCreationDisabled = 6_000,
SlippageExceeded = 6_001,
AlreadyMigrated = 6_002,
ThresholdNotReached = 6_003,
ThresholdReached = 6_004,
InvalidBaseMint = 6_005,
InvalidQuoteMint = 6_006,
NotTradeable = 6_007,
InvalidStatusTransition = 6_008,
CurveIsLive = 6_009,
BaseMintNotFound = 6_010,
BlockedByHeldSupply = 6_011,
InvalidCoinCreator = 6_012,
InvalidAuthority = 6_013,
InsufficientBalance = 6_014,
PoolFeesOutstanding = 6_015,
ProgramPaused = 7_000,
Unauthorized = 7_001,
ArithmeticOverflow = 7_002,
InvalidPythAccount = 7_003,
InvalidPythFeed = 7_004,
InvalidSlug = 7_005,
TextTooLong = 7_006,
UserTokenAccountWrongProgram = 7_007,
UserTokenAccountInvalid = 7_008,
UserTokenAccountWrongMint = 7_009,
UserTokenAccountWrongAuthority = 7_010,
NothingToClaim = 7_011,
Unused7012 = 7_012,
QuoteMintPriceUnset = 7_013,
TransferFeeNotSettleable = 7_014,
CreatorFeeTooHigh = 7_015,
CreatorFeeModeNotAllowed = 7_016,
InsufficientLiquidity = 7_100,
InvalidAmount = 7_101,
}Variants
TokenCreationDisabled = 6_000
6000 - Token creation is disabled
SlippageExceeded = 6_001
6001 - Slippage tolerance exceeded
AlreadyMigrated = 6_002
6002 - Already migrated
ThresholdNotReached = 6_003
6003 - Migration threshold not reached
ThresholdReached = 6_004
6004 - Migration threshold reached - trading disabled until migration completes
InvalidBaseMint = 6_005
6005 - Invalid base mint
InvalidQuoteMint = 6_006
6006 - Invalid quote mint
NotTradeable = 6_007
6007 - Bonding curve is not tradeable
InvalidStatusTransition = 6_008
6008 - Invalid status transition
CurveIsLive = 6_009
6009 - Curve is live
BaseMintNotFound = 6_010
6010 - Base mint not found
BlockedByHeldSupply = 6_011
6011 - Blocked by held supply
InvalidCoinCreator = 6_012
6012 - Invalid coin creator
InvalidAuthority = 6_013
6013 - Invalid authority
InsufficientBalance = 6_014
6014 - Insufficient balance in source account
PoolFeesOutstanding = 6_015
6015 - Pool has unclaimed protocol or creator fees
ProgramPaused = 7_000
7000 - Program is paused
7001 - Unauthorized
ArithmeticOverflow = 7_002
7002 - Arithmetic overflow
InvalidPythAccount = 7_003
7003 - Invalid Pyth price account
InvalidPythFeed = 7_004
7004 - Invalid Pyth feed ID
InvalidSlug = 7_005
7005 - Invalid slug: must be non-empty, <= max_len bytes, lowercase alphanumeric or underscore
TextTooLong = 7_006
7006 - Text too long
UserTokenAccountWrongProgram = 7_007
7007 - User token account owned by the wrong token program
UserTokenAccountInvalid = 7_008
7008 - User token account is not an initialized token account
UserTokenAccountWrongMint = 7_009
7009 - User token account mint does not match the trade
UserTokenAccountWrongAuthority = 7_010
7010 - User token account is not owned by the trading user
NothingToClaim = 7_011
7011 - Nothing to claim
Unused7012 = 7_012
7012 - Unused
QuoteMintPriceUnset = 7_013
7013 - Quote mint has no USDC price on its nexus reward state
TransferFeeNotSettleable = 7_014
7014 - Token-2022 transfer fee schedule cannot settle the exact amount
CreatorFeeTooHigh = 7_015
7015 - Creator fee exceeds the partner’s maximum
CreatorFeeModeNotAllowed = 7_016
7016 - Creator fee mode is not allowed by the partner config
InsufficientLiquidity = 7_100
7100 - Insufficient liquidity
InvalidAmount = 7_101
7101 - Invalid amount