CreateTokenCpiBuilder

Struct CreateTokenCpiBuilder 

pub struct CreateTokenCpiBuilder<'a, 'b> { /* private fields */ }
Instruction builder for CreateToken via CPI.

Accounts:

  1. [writable, signer] user
  2. [writable, signer] payer
  3. [] coin_creator
  4. [] global_config
  5. [writable, signer] base_mint
  6. [] quote_mint
  7. [writable] bonding_curve
  8. [writable] base_vault
  9. [writable] quote_vault
  10. [writable] creator_fee_config
  11. [] nexus_program
  12. [] nexus_global_config
  13. [signer] partner
  14. [] partner_config
  15. [] nexus_staking_config
  16. [writable] staking_reward_state
  17. [writable] reward_accrual
  18. [writable] staking_vault
  19. [writable] staking_wsol_vault
  20. [writable] wsol_reward_accrual
  21. [] pyth_price_feed
  22. [] base_token_program
  23. [] quote_token_program
  24. [] wsol_token_program
  25. [] associated_token_program
  26. [] system_program
  27. [] event_authority
  28. [] program

Implementations

Source

impl<'a, 'b> CreateTokenCpiBuilder<'a, 'b>

pub fn new( __program: &'b AccountInfo<'a>, user: &'b AccountInfo<'a>, payer: &'b AccountInfo<'a>, coin_creator: &'b AccountInfo<'a>, global_config: &'b AccountInfo<'a>, base_mint: &'b AccountInfo<'a>, quote_mint: &'b AccountInfo<'a>, bonding_curve: &'b AccountInfo<'a>, base_vault: &'b AccountInfo<'a>, quote_vault: &'b AccountInfo<'a>, creator_fee_config: &'b AccountInfo<'a>, nexus_program: &'b AccountInfo<'a>, nexus_global_config: &'b AccountInfo<'a>, partner: (&'b AccountInfo<'a>, bool), partner_config: &'b AccountInfo<'a>, nexus_staking_config: &'b AccountInfo<'a>, staking_reward_state: &'b AccountInfo<'a>, reward_accrual: &'b AccountInfo<'a>, staking_vault: &'b AccountInfo<'a>, staking_wsol_vault: &'b AccountInfo<'a>, wsol_reward_accrual: &'b AccountInfo<'a>, pyth_price_feed: &'b AccountInfo<'a>, base_token_program: &'b AccountInfo<'a>, quote_token_program: &'b AccountInfo<'a>, wsol_token_program: &'b AccountInfo<'a>, associated_token_program: &'b AccountInfo<'a>, system_program: &'b AccountInfo<'a>, event_authority: &'b AccountInfo<'a>, program: &'b AccountInfo<'a>, platform_config: Address, creator_platform: String, creator_id: String, creator_hash: Address, name: String, symbol: String, uri: String, ) -> Self

pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self

Add an additional account to the instruction.

pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self

Add additional accounts to the instruction.

Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not, and a bool indicating whether the account is a signer or not.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult