pub struct CreateTokenInstructionArgs {
pub platform_config: Address,
pub creator_platform: String,
pub creator_id: String,
pub creator_hash: Address,
pub name: String,
pub symbol: String,
pub uri: String,
}Fields
platform_config: Addresscreator_platform: Stringcreator_id: Stringcreator_hash: Addressname: Stringsymbol: Stringuri: StringTrait Implementations
Sourceimpl BorshDeserialize for CreateTokenInstructionArgs
impl BorshDeserialize for CreateTokenInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateTokenInstructionArgs
impl Clone for CreateTokenInstructionArgs
Sourcefn clone(&self) -> CreateTokenInstructionArgs
fn clone(&self) -> CreateTokenInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateTokenInstructionArgs
impl Debug for CreateTokenInstructionArgs
Sourceimpl<'de> Deserialize<'de> for CreateTokenInstructionArgs
impl<'de> Deserialize<'de> for CreateTokenInstructionArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CreateTokenInstructionArgs
impl StructuralPartialEq for CreateTokenInstructionArgs