pub struct SellQuote {
pub base_amount: u64,
pub quote_amount: u64,
pub fee: u64,
pub base_transfer_fee: u64,
pub quote_transfer_fee: u64,
pub base_from_user: u64,
pub quote_to_user: u64,
}Expand description
Same field rules as BuyQuote.
Fields
base_amount: u64quote_amount: u64fee: u64Platform fee, in quote units, on the quote output of the AMM before the fee.
base_transfer_fee: u64quote_transfer_fee: u64base_from_user: u64The base that the seller sends, with the transfer fee. Equals
base_amount.
quote_to_user: u64The quote that the seller receives, after the quote mint’s transfer fee.