pub struct AuthPlatformEntry {
pub name: String,
pub enabled: bool,
}Fields
name: Stringenabled: boolTrait Implementations
Sourceimpl BorshDeserialize for AuthPlatformEntry
impl BorshDeserialize for AuthPlatformEntry
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AuthPlatformEntry
impl BorshSerialize for AuthPlatformEntry
Sourceimpl Clone for AuthPlatformEntry
impl Clone for AuthPlatformEntry
Sourceimpl Debug for AuthPlatformEntry
impl Debug for AuthPlatformEntry
Sourceimpl<'de> Deserialize<'de> for AuthPlatformEntry
impl<'de> Deserialize<'de> for AuthPlatformEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AuthPlatformEntry
Sourceimpl PartialEq for AuthPlatformEntry
impl PartialEq for AuthPlatformEntry
Sourceimpl Serialize for AuthPlatformEntry
impl Serialize for AuthPlatformEntry
impl StructuralPartialEq for AuthPlatformEntry