#[non_exhaustive]pub enum Clash {
WritableDuplicate,
ExtraUnresolved,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WritableDuplicate
The hook repeats an account of the trade, and one copy is writable. A swap with it fails. A read-only hook repeat of the market is not a clash.
ExtraUnresolved