#[non_exhaustive]pub enum HookError {
NotLoaded,
NoList,
Unresolvable(Unresolvable),
Clash(Clash),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotLoaded
NoList
The validation account is missing, or the hook program does not own it. Token-2022 still calls the hook, and the transfer fails.
Unresolvable(Unresolvable)
Clash(Clash)
A clash of this swap only, for example with this trader’s accounts.