#[non_exhaustive]pub enum Unresolvable {
Show 13 variants
MalformedList,
NoExecuteEntry,
ListTooLong,
MalformedExtra,
MalformedSeed,
TooManySeeds,
SeedTooLong,
ExtraSigns,
ReadsTransferAmount,
ReadsPastInstructionData,
NamesUnresolvedAccount,
ReadsSwapTimeData,
Clash(Clash),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MalformedList
NoExecuteEntry
ListTooLong
An extra is at an account index above 255.
MalformedExtra
MalformedSeed
TooManySeeds
A PDA has more than 15 seeds. The bump is the 16th.
SeedTooLong
ExtraSigns
ReadsTransferAmount
A seed reads the transfer amount. The program sets the amount of one leg during the swap.
ReadsPastInstructionData
An extra reads a pubkey from the Execute data. The data is 16 bytes,
shorter than a pubkey.
NamesUnresolvedAccount
ReadsSwapTimeData
Clash(Clash)
A clash that MarketHooks::screen finds. It applies to every trader.