#[non_exhaustive]pub struct MarketQuote {
pub in_amount: u64,
pub out_amount: u64,
pub fee: u64,
pub fee_bps: u16,
pub supply_capped: bool,
}Expand description
The trade that the program would make. The caller decides whether to send it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.in_amount: u64The amount that the user sends, with the input mint’s transfer fee.
out_amount: u64The amount that the user receives, after the output mint’s transfer fee.
fee: u64Platform fee, in quote units.
fee_bps: u16Platform fee rate in bps, with the fee decay premium.
supply_capped: booltrue when the supply left on the curve makes the fill smaller than the
request. The program fills a capped ExactIn buy. It refuses a capped
ExactOut buy.