pub enum SendDexError {
Show 30 variants
PoolPaused = 6_000,
SlippageExceeded = 6_001,
InsufficientBalance = 6_002,
InvalidBaseMint = 6_003,
InvalidQuoteMint = 6_004,
PoolCreationDisabled = 6_005,
InvalidPoolState = 6_006,
InvalidDeposit = 6_007,
InvalidPoolBalance = 6_008,
InsufficientPoolBalance = 6_009,
InvalidAuthority = 6_010,
InvalidCreatorHash = 6_011,
InvalidPlatformConfig = 6_012,
ProgramPaused = 7_000,
Unauthorized = 7_001,
ArithmeticOverflow = 7_002,
InvalidPythAccount = 7_003,
InvalidPythFeed = 7_004,
InvalidSlug = 7_005,
TextTooLong = 7_006,
UserTokenAccountWrongProgram = 7_007,
UserTokenAccountInvalid = 7_008,
UserTokenAccountWrongMint = 7_009,
UserTokenAccountWrongAuthority = 7_010,
NothingToClaim = 7_011,
InvalidCreatorId = 7_012,
QuoteMintPriceUnset = 7_013,
TransferFeeNotSettleable = 7_014,
InsufficientLiquidity = 7_100,
InvalidAmount = 7_101,
}Variants
PoolPaused = 6_000
6000 - Pool is paused
SlippageExceeded = 6_001
6001 - Slippage tolerance exceeded
InsufficientBalance = 6_002
6002 - Insufficient balance in source account
InvalidBaseMint = 6_003
6003 - Invalid base mint
InvalidQuoteMint = 6_004
6004 - Invalid quote mint
PoolCreationDisabled = 6_005
6005 - Pool creation is disabled
InvalidPoolState = 6_006
6006 - Invalid pool state
InvalidDeposit = 6_007
6007 - Invalid deposit
InvalidPoolBalance = 6_008
6008 - Invalid pool balance
InsufficientPoolBalance = 6_009
6009 - Insufficient pool balance
InvalidAuthority = 6_010
6010 - Invalid authority
InvalidCreatorHash = 6_011
6011 - creator_hash does not match (creator_platform, creator_id)
InvalidPlatformConfig = 6_012
6012 - Platform config cannot be the default address
ProgramPaused = 7_000
7000 - Program is paused
7001 - Unauthorized
ArithmeticOverflow = 7_002
7002 - Arithmetic overflow
InvalidPythAccount = 7_003
7003 - Invalid Pyth price account
InvalidPythFeed = 7_004
7004 - Invalid Pyth feed ID
InvalidSlug = 7_005
7005 - Invalid slug: must be non-empty, <= max_len bytes, lowercase alphanumeric or underscore
TextTooLong = 7_006
7006 - Text too long
UserTokenAccountWrongProgram = 7_007
7007 - User token account owned by the wrong token program
UserTokenAccountInvalid = 7_008
7008 - User token account is not an initialized token account
UserTokenAccountWrongMint = 7_009
7009 - User token account mint does not match the trade
UserTokenAccountWrongAuthority = 7_010
7010 - User token account is not owned by the trading user
NothingToClaim = 7_011
7011 - Nothing to claim
InvalidCreatorId = 7_012
7012 - Creator identity is not a decodable wallet address
QuoteMintPriceUnset = 7_013
7013 - Quote mint has no USDC price on its nexus reward state
TransferFeeNotSettleable = 7_014
7014 - Token-2022 transfer fee schedule cannot settle the exact amount
InsufficientLiquidity = 7_100
7100 - Insufficient liquidity
InvalidAmount = 7_101
7101 - Invalid amount