pub struct CreateTokenCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for CreateToken via CPI.
Accounts:
[writable, signer]user[writable, signer]payer[]coin_creator[]global_config[writable, signer]base_mint[]quote_mint[writable]bonding_curve[writable]base_vault[writable]quote_vault[writable]creator_fee_config[]nexus_program[]nexus_global_config[signer]partner[]partner_config[]nexus_staking_config[writable]staking_reward_state[writable]reward_accrual[writable]staking_vault[writable]staking_wsol_vault[writable]wsol_reward_accrual[]pyth_price_feed[]base_token_program[]quote_token_program[]wsol_token_program[]associated_token_program[]system_program[]event_authority[]program
Implementations
Sourceimpl<'a, 'b> CreateTokenCpiBuilder<'a, 'b>
impl<'a, 'b> CreateTokenCpiBuilder<'a, 'b>
pub fn new( __program: &'b AccountInfo<'a>, user: &'b AccountInfo<'a>, payer: &'b AccountInfo<'a>, coin_creator: &'b AccountInfo<'a>, global_config: &'b AccountInfo<'a>, base_mint: &'b AccountInfo<'a>, quote_mint: &'b AccountInfo<'a>, bonding_curve: &'b AccountInfo<'a>, base_vault: &'b AccountInfo<'a>, quote_vault: &'b AccountInfo<'a>, creator_fee_config: &'b AccountInfo<'a>, nexus_program: &'b AccountInfo<'a>, nexus_global_config: &'b AccountInfo<'a>, partner: (&'b AccountInfo<'a>, bool), partner_config: &'b AccountInfo<'a>, nexus_staking_config: &'b AccountInfo<'a>, staking_reward_state: &'b AccountInfo<'a>, reward_accrual: &'b AccountInfo<'a>, staking_vault: &'b AccountInfo<'a>, staking_wsol_vault: &'b AccountInfo<'a>, wsol_reward_accrual: &'b AccountInfo<'a>, pyth_price_feed: &'b AccountInfo<'a>, base_token_program: &'b AccountInfo<'a>, quote_token_program: &'b AccountInfo<'a>, wsol_token_program: &'b AccountInfo<'a>, associated_token_program: &'b AccountInfo<'a>, system_program: &'b AccountInfo<'a>, event_authority: &'b AccountInfo<'a>, program: &'b AccountInfo<'a>, platform_config: Address, creator_platform: String, creator_id: String, creator_hash: Address, name: String, symbol: String, uri: String, ) -> Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult