pub enum SendNexusError {
Show 47 variants
InsufficientStake = 6_000,
InvalidRewardMint = 6_001,
InvalidVault = 6_002,
StakingAlreadyEnabled = 6_005,
StakingNotEnabled = 6_006,
InvalidStakingMint = 6_007,
InvalidRewardState = 6_008,
InvalidMint = 6_009,
InvalidDestination = 6_010,
StakingMintAlreadyBound = 6_011,
InvalidFeePreset = 6_012,
InvalidPresetIndex = 6_013,
MissingFeeSource = 6_014,
AmbiguousFeeSource = 6_015,
InvalidPartnerName = 6_016,
PartnerNotOnPreset = 6_017,
InvalidPartnerNote = 6_018,
InvalidPresetName = 6_019,
TooManyAuthPlatforms = 6_020,
InvalidAuthPlatformIndex = 6_021,
InvalidAuthPlatformName = 6_022,
DuplicateAuthPlatformName = 6_023,
InvalidAuthority = 6_024,
ReservedPartner = 6_025,
InvalidRewardAccrual = 6_026,
RewardsNotSettled = 6_027,
InvalidUsdcPrice = 6_028,
InvalidPlatformConfig = 6_029,
InvalidPartnerConfig = 6_030,
PresetPlatformMismatch = 6_031,
ProgramPaused = 7_000,
Unauthorized = 7_001,
ArithmeticOverflow = 7_002,
InvalidPythAccount = 7_003,
InvalidPythFeed = 7_004,
InvalidSlug = 7_005,
TextTooLong = 7_006,
UserTokenAccountWrongProgram = 7_007,
UserTokenAccountInvalid = 7_008,
UserTokenAccountWrongMint = 7_009,
UserTokenAccountWrongAuthority = 7_010,
NothingToClaim = 7_011,
InvalidCreatorId = 7_012,
QuoteMintPriceUnset = 7_013,
TransferFeeNotSettleable = 7_014,
InsufficientLiquidity = 7_100,
InvalidAmount = 7_101,
}Variants
InsufficientStake = 6_000
6000 - Insufficient stake balance
InvalidRewardMint = 6_001
6001 - Invalid reward mint
InvalidVault = 6_002
6002 - Invalid vault
StakingAlreadyEnabled = 6_005
6005 - Staking already enabled
StakingNotEnabled = 6_006
6006 - Staking not enabled
InvalidStakingMint = 6_007
6007 - Invalid staking mint
InvalidRewardState = 6_008
6008 - Invalid reward state
InvalidMint = 6_009
6009 - Invalid mint
InvalidDestination = 6_010
6010 - Invalid destination account
StakingMintAlreadyBound = 6_011
6011 - Staking mint already bound
InvalidFeePreset = 6_012
6012 - Invalid fee configuration
InvalidPresetIndex = 6_013
6013 - Invalid preset index
MissingFeeSource = 6_014
6014 - Must provide either fee_preset or custom fees
AmbiguousFeeSource = 6_015
6015 - Cannot specify both fee_preset and custom_fees
InvalidPartnerName = 6_016
6016 - Partner name cannot be empty
PartnerNotOnPreset = 6_017
6017 - Partner account does not use this preset
InvalidPartnerNote = 6_018
6018 - Invalid partner note
InvalidPresetName = 6_019
6019 - Invalid preset name
TooManyAuthPlatforms = 6_020
6020 - Too many auth platforms (max 255)
InvalidAuthPlatformIndex = 6_021
6021 - Invalid auth platform index
InvalidAuthPlatformName = 6_022
6022 - Invalid auth platform name
DuplicateAuthPlatformName = 6_023
6023 - Duplicate auth platform name
InvalidAuthority = 6_024
6024 - Invalid authority
ReservedPartner = 6_025
6025 - Cannot add the default partner
InvalidRewardAccrual = 6_026
6026 - Invalid reward accrual
RewardsNotSettled = 6_027
6027 - Settle every reward mint before staking or unstaking - call settle for each registered mint
InvalidUsdcPrice = 6_028
6028 - USDC price must be non-zero - 0 means no price
InvalidPlatformConfig = 6_029
6029 - Platform config cannot be the default address
InvalidPartnerConfig = 6_030
6030 - Partner config address does not match its stored seeds
PresetPlatformMismatch = 6_031
6031 - Fee preset belongs to a different platform
ProgramPaused = 7_000
7000 - Program is paused
7001 - Unauthorized
ArithmeticOverflow = 7_002
7002 - Arithmetic overflow
InvalidPythAccount = 7_003
7003 - Invalid Pyth price account
InvalidPythFeed = 7_004
7004 - Invalid Pyth feed ID
InvalidSlug = 7_005
7005 - Invalid slug: must be non-empty, <= max_len bytes, lowercase alphanumeric or underscore
TextTooLong = 7_006
7006 - Text too long
UserTokenAccountWrongProgram = 7_007
7007 - User token account owned by the wrong token program
UserTokenAccountInvalid = 7_008
7008 - User token account is not an initialized token account
UserTokenAccountWrongMint = 7_009
7009 - User token account mint does not match the trade
UserTokenAccountWrongAuthority = 7_010
7010 - User token account is not owned by the trading user
NothingToClaim = 7_011
7011 - Nothing to claim
InvalidCreatorId = 7_012
7012 - Creator identity is not a decodable wallet address
QuoteMintPriceUnset = 7_013
7013 - Quote mint has no USDC price on its nexus reward state
TransferFeeNotSettleable = 7_014
7014 - Token-2022 transfer fee schedule cannot settle the exact amount
InsufficientLiquidity = 7_100
7100 - Insufficient liquidity
InvalidAmount = 7_101
7101 - Invalid amount